=begin
(c) TIG 2010

accessibleaxes.rb

'Accessible Axes'

Shows Axes labeled XYZ, in heavier colored/patterned lines, 
intended to assist color-blind users.
Shortcut to it in Plugins menu, e.g. shift+A, press <Esc> to close.
Reverts to 'Select' tool.

=end
require 'sketchup.rb'
class AccessibleAxes

def activate()
  @model=Sketchup.active_model
  @ents=@model.active_entities
  @txts=[]
  @txt="Accessible Axes: press <Esc> to close..."
  Sketchup::set_status_text(@txt)
  #Sketchup.send_action("viewShowAxes:")
  self.draw(@model.active_view)
  @model.active_view.invalidate
end

def deactivate(view)
  view.invalidate
  @txts.each{|e|e.erase! if e.valid?}if @txts
  Sketchup.send_action("selectSelectionTool:")
  return nil
end

def onCancel(reason,view)
  self.deactivate(view)
end

def resume(view)
  Sketchup::set_status_text(@txt)
  self.draw(view)
  view.invalidate
end

def enableVCB?
  return false
end

def draw(view)
  ### X red
  view.drawing_color="red"
  view.line_width=5
  view.line_stipple=""
  view.draw_line([0,0,0],[100,0,0])
  @txts<< @ents.add_text("X [Red]",[10,0,0],[1,1,1])
  @txts[-1].arrow_type=2
  ### Y green
  view.drawing_color="green"
  view.line_width=5
  view.line_stipple="-.-"
  view.draw_line([0,0,0],[0,100,0])
  @txts<< @ents.add_text("Y [Green]",[0,10,0],[-1,1,1])
  @txts[-1].arrow_type=2
  ### Z blue
  view.drawing_color="blue"
  view.line_width=5
  view.line_stipple="."
  view.draw_line([0,0,0],[0,0,100])
  @txts<< @ents.add_text("Z [Blue]",[0,0,10],[1,1,1])
  @txts[-1].arrow_type=2
  ###
end

end#class
### shortcut defn
def accessibleaxes()
  Sketchup.active_model.select_tool(AccessibleAxes.new)
end#def
### menu
if not file_loaded?(__FILE__)
    textstring="Accessible Axes"
    instructions=": Shows Axes more clearly, use through a shortcut then press enter to close..."
    cmd=UI::Command.new(textstring){accessibleaxes()}
    UI.menu("Plugins").add_item(textstring){accessibleaxes()}
    cmd.status_bar_text=textstring+instructions
end
#-----------------------------------------------------------------------------
file_loaded(__FILE__)
###